==> kadu_0.11.1.orig.tar.bz2: kadu-0.11.1/plugins/filedesc/translations/filedesc_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>FileDesc</source>
        <translation>Popis souboru</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Soubor s popisem k seřízení</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Zde zadejte soubor, který bude obsahovat popisy k obnově modulem.</translation>
    </message>
    <message>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Vynutit stav na &apos;s popisem&apos;</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Pokud zvolíte stav bez popisu, modul jej nastaví automaticky na podobný ale s popisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Povolit jiné popisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/filedesc/translations/filedesc_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>FileDesc</source>
        <translation>Popis souboru</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Soubor s popisem k seřízení</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Zde zadejte soubor, který bude obsahovat popisy k obnově modulem.</translation>
    </message>
    <message>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Vynutit stav na &apos;s popisem&apos;</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Pokud zvolíte stav bez popisu, modul jej nastaví automaticky na podobný ale s popisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Povolit jiné popisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Umožní vám nastavit některé vlastní popisy ručně, dokud se obsah souboru nezmění</translation>
    </message>
</context>
</TS>
